<?php
/**
 * Dorian functions and definitions
 *
 * @package Dorian
 */
 
/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 750; /* pixels */
}

if ( ! function_exists( 'dorian_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function dorian_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Dorian, use a find and replace
	 * to change 'dorian' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'dorian', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	global $content_width;
	add_theme_support( 'post-thumbnails' );
	//Add additional thumbnail size: featured image is optimized for retina screens 
	set_post_thumbnail_size( 'featured-photo', $content_width * 2, 1200, false );
	//Add image sizes: select these options in the Media Library if you want retina-ready images  
	add_image_size( 'large-photo', $content_width * 2, $content_width * 2, true );
	add_image_size( 'medium-photo', $content_width, $content_width, false );
	add_image_size( 'small-photo', 300, 300, true );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'dorian' ),
		'social' => __( 'Social Menu', 'dorian' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'status', 'image', 'gallery', 'video', 'quote', 'link', 'aside', 'audio', 'chat'
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'dorian_custom_background_args', array(
		'default-color' => 'e0e0e0',
		'default-image' => '',
	) ) );
	
}
endif; // dorian_setup
add_action( 'after_setup_theme', 'dorian_setup' );

/**
 * Enable user selection of added image sizes from the media library panel.
 * @link http://codex.wordpress.org/Plugin_API/Filter_Reference/image_size_names_choose
 */
add_filter( 'image_size_names_choose', 'dorian_custom_image_sizes' );  
function dorian_custom_image_sizes( $sizes ) {  
    $custom_sizes = array(  
        'large-photo' => __( 'Retina large image', 'dorian' ),
        'medium-photo' => __( 'Retina medium image', 'dorian' ),
        'small-photo' => __( 'Retina small image', 'dorian' )
    );
    return array_merge( $sizes, $custom_sizes );  
}

/**
 * Register widget areas.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function dorian_widgets_init() {
	
	register_sidebar( array(
		'name'          => __( 'First footer column', 'dorian' ),
		'id'            => 'sidebar-footer-1',
		'description'   => __( 'First column in footer widget area', 'dorian' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Second footer column', 'dorian' ),
		'id'            => 'sidebar-footer-2',
		'description'   => __( 'Second column in footer widget area', 'dorian' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'dorian_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function dorian_scripts() {
	//Customized Twitter Bootstrap CSS 
	wp_enqueue_style( 'dorian-boostrap-style', get_template_directory_uri() . '/css/bootstrap.min.css' );
	
	// FontAwesome
    wp_enqueue_style('dorian-fontawesome', get_template_directory_uri() . '/fonts/font-awesome.min.css');
	
	// Superfish jQuery menu plugin
    wp_enqueue_style('dorian-superfish', get_template_directory_uri() . '/css/superfish.css');
	
	//Theme CSS
	wp_enqueue_style( 'dorian-style', get_stylesheet_uri() );
	
	//JS scripts 
	wp_enqueue_script( 'dorian-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	
	wp_enqueue_script( 'dorian-enquire', get_template_directory_uri() . '/js/enquire.min.js', array('jquery'), '', true );
	
	wp_enqueue_script( 'dorian-superfish', get_template_directory_uri() . '/js/superfish.min.js', array('jquery'), '', true );
	
	wp_enqueue_script( 'dorian-scripts', get_template_directory_uri() . '/js/dorian.js', array('jquery'), '', true );

	wp_enqueue_script( 'dorian-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'dorian_scripts' );

/**
 * Returns the Google font stylesheet URL, if available.
 *
 * Code from http://themeshaper.com/2014/08/13/how-to-add-google-fonts-to-wordpress-themes/  
 * by Fränk Klein
 *
 * The use of Italianno and Playfair Display by default is
 * localized. For languages that use characters not supported by either
 * font, the font can be disabled.
 *
 * @since Dorian 1.0
 *
 * @return string Font stylesheet or empty string if disabled.
 */
function dorian_fonts_url() {
	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Italianno, translate this to 'off'. Do not
	 * translate into your own language.
	 */
	$italianno = _x( 'on', 'Italianno font: on or off', 'dorian' );

	/* Translators: If there are characters in your language that are not
	 * supported by Playfair Display, translate this to 'off'. Do not
	 * translate into your own language.
	 */
	$playfair_display = _x( 'on', 'Playfair Display font: on or off', 'dorian' );

	if ( 'off' !== $italianno || 'off' !== $playfair_display ) {
		$font_families = array();

		if ( 'off' !== $italianno )
			$font_families[] = 'Italianno';

		if ( 'off' !== $playfair_display )
			$font_families[] = 'Playfair+Display:400,400italic,700,700italic';

		$protocol = is_ssl() ? 'https' : 'http';
		$query_args = array(
			'family' => implode( '|', $font_families ),
			'subset' => 'latin,latin-ext',
		);
		$fonts_url = add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" );
	}

	return $fonts_url;
}

/**
 * Loads our special font CSS file.
 *
 * To disable in a child theme, use wp_dequeue_style()
 * function mytheme_dequeue_fonts() {
 *     wp_dequeue_style( 'dorian-fonts' );
 * }
 * add_action( 'wp_enqueue_scripts', 'mytheme_dequeue_fonts', 11 );
 *
 * @since Dorian 1.0
 *
 * @return void
 */
function dorian_fonts() {
	$fonts_url = dorian_fonts_url();
	if ( ! empty( $fonts_url ) )
		wp_enqueue_style( 'dorian-fonts', esc_url_raw( $fonts_url ), array(), null );
}
add_action( 'wp_enqueue_scripts', 'dorian_fonts' );

/**
 * Adds the editor style and includes our special fonts in it.
 *
 * @since Dorian 1.0
 *
 * @return void
 */
function dorian_editor_styles() {
    add_editor_style( array( 'css/bootstrap.min.css', 'css/editor-style.css', 'fonts/font-awesome.min.css', dorian_fonts_url() ) );
}
add_action( 'after_setup_theme', 'dorian_editor_styles' );

global $wp_embed;
add_filter( 'the_excerpt', array( $wp_embed, 'autoembed' ), 9 );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Adds our special fonts to the Custom Header panel.
 *
 * @since Dorian 1.0
 *
 * @return void
 */
function dorian_custom_header_fonts() {
    wp_enqueue_style( 'dorian-fonts', dorian_fonts_url(), array(), null );
}
add_action( 'admin_print_styles-appearance_page_custom-header', 'dorian_custom_header_fonts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
